'Tesseract.dll loader'

import os
import clr # type: ignore

clr.AddReference(
    os.path.join(
        os.path.dirname(__file__),
        'Tesseract.dll'
    ),
)
clr.AddReference('System.Drawing')
from System.Drawing import Image, Bitmap # type: ignore
from Tesseract import TesseractEngine, PixConverter, EngineMode # type: ignore

__all__ = (
    'TesseractEngine', 'PixConverter', 'EngineMode', 'Image', 'Bitmap'
)


'tesseractpy - Tesseract C# wrapper wrapped in Python'

from os.path import abspath
from pkgutil import iter_modules

__all__ = (
    'EngineMode',
    'TesseractEngine',
    'PixConverter',
    'BitmapFromFile',
    'Init',
)

def Init():
    modules = [module.name for module in iter_modules()]

    if 'pythonnet' not in modules:
        from subprocess import call, PIPE

        call('pip install pythonnet --pre', stdout=PIPE, stderr=PIPE)

    global EngineMode, TesseractEngine, PixConverter, Image, Bitmap
    from .loader import EngineMode, TesseractEngine, PixConverter, Image, Bitmap

    return None

def BitmapFromFile(file, *args):
    image = Image.FromFile(abspath(file))
    return Bitmap(image, *args)


from typing import Any
from _typeshed import StrPath, NoneType

class TesseractEngine:
    '''No documentation for this class.'''
    def __init__(
        self,
        data: StrPath | NoneType = ...,
        language: str | NoneType = ...,
        mode: Any | NoneType = ...,
        /,
    ) -> NoneType: ...

class EngineMode:
    'Engine mode group for tesseractpy.TesseractEngine'

class PixConverter:
    'No documentation for this class.'

def Init() -> NoneType: ...
def BitmapFromFile(file: StrPath, *args) -> Any: ...


from setuptools import setup

setup(
    name='tesseractpy',
    version='1.0.0',
    description='tesseractpy - Tesseract C# wrapper wrapped in Python',
    author='LUA9',
    maintainer='LUA9',
    packages=['tesseractpy'],
    include_package_data=True,
)